COM 4705 Introduction to Natural Language Processing 2024 Fall

Note: The syllabus is subject to change. Please check this page frequently for any updated information.

Class Time

| Time | Location |
| :---- | :---- |
| Mon 4:10 pm \- 5:25 pm | Mudd 451 |
| Wed 4:10 pm \- 5:25 pm | Mudd 451 |

Instructor Office Hours

| Time | Location |
| :---- | :---- |
| Monday 9:30-11 am | Schapiro CEPSR 723 |

TAs and their office hours, location:

| TA | Office Hour | location |
| :---- | :---- | :---- |
| Siyan Li | Tuesdays 9:30 am \- 11:30 am | Schapiro CEPSR 7th Floor Lounge |
| Zachary Horvitz | Tuesdays 3:00 pm \- 5:00 pm | Schapiro CEPSR 724 |
| Matthew Toles | Wednesday 11:00am \- 1:00pm | Schapiro CEPSR 725 <http://meet.google.com/oaj-fwdz-ryt> |
| Xiao Yu | Thursday 4:30 pm \- 6:30 pm | Schapiro CEPSR 7th Floor Lounge(*checkout CEPSR 7LE5 if I am not there*) |
| Xuanming Zhang | Friday 2:00 pm \- 4:00 pm | Schapiro CEPSR 713 |

Discussion Policy

This class has a Ed Discussion section for students to ask and discuss all kinds of questions regarding lectures, homework, and exams.  While TAs and Instructors will answer questions, all the students are also welcome to post their solutions to help their classmates. We strongly encourage students to respond to questions on the Ed Discussion at the end of the semester, 5 students with the most instructor-endorsed responses will receive a 3% extra credit to their final grade.  
Attendance Policy  
**Attendance Form:** [https://forms.gle/vzsRBEYyXy4AxTzD7](https://forms.gle/vzsRBEYyXy4AxTzD7)
When attendance is being taken during a class session, an attendance code will be provided to all students. To mark your attendance:  
1\.  Access the provided Attendance Form link.  
2\.  Enter the given attendance code.  
3\.  Ensure you submit the form by no later than 2:30 am on the following day.  
Submissions after the 12-hour deadline will not be considered as present for that class.  
You will receive full mark if you attend at least 80% of the courses

Email Policy  
If you have a question that is not confidential or personal, post it on the Ed Discussion forum \- responses tend to be quicker and have a wider audience. To contact the teaching staff directly, we strongly encourage you to come during office hours.  Please don't email individual staff members. If you have a matter to be discussed privately, please come to office hours, or make an appointment in person. For grading questions, please talk to us during office hours.

Regrade Policy  
Regrade Requests  
If you feel you deserve a better grade on an assignment or a quiz, you may submit a regrade request to the course email within two days after the grades are released. Your request should briefly summarize why you feel the original grade was unfair. Your TA will reevaluate your assignment as soon as possible and then issue a decision. If you are still not happy, you can ask for your assignment to be graded by an instructor.  

Honor Code  
Since we occasionally reuse assignments from previous years, we expect students not to copy, refer to, or look at the solutions in preparing their answers. It is an honor code violation to intentionally refer to a previous year's solutions. This applies both to the official solutions and to solutions that you or someone else may have written up in the previous year. It is also an honor code violation to find some way to look at the test set or interfere in any way with programming assignment scoring or tampering with the submitted script.  
Cheating Policy  
Please see [the document](https://drive.google.com/file/d/13Isd1SRSfZtjZ41YD7D70ht1S6D32xrs/view?usp=sharing). Please also refer to the university's code of conduct:  
Grades

| Homework | 51% |
| :---- | :---- |
| Midterm | 17% |
| Final | 20% |
| Attendance | 12% |
| Ed Discussion (extra credit) | 3% |

Homework Grading  
You will be given a total of 4 days of late days for all homework throughout the semester. If all the late days are used up, work that is up to 48 hours late will still be credited, but with an extra 10% deduction for every 12 hours past the deadline. Please notice that as we have already given you some late days for any kind of exception for late homework, once the late days are used up, we will accept no exception excuse to waive the late homework penalty, which includes doctor's notice and all kinds of uploading issues at the last minute.  

Textbooks  
There is no required textbook, but I will expect you to know the material listed above, drawn from the textbooks and other readings. The material in the readings will be tested on the final exam. Different people may learn better from different combinations of videos/lectures, reading the chapters, or coming to the in-class group exercises. The best-prepared students who do the best on the final exams tend to do all three. Attendance is taken by filling a form after every lecture. Online new chapters from [Jurafsky and Martin. third edition in progress. Speech and Language Processing.](http://web.stanford.edu/~jurafsky/slp3/)

Course Schedule

| Date | Lecture Name | Homework | Book | Slides |
| :---- | :---- | :---- | :---- | :---- |
| Sept 4 | Introduction |  |  | [Link](https://docs.google.com/presentation/d/1CslRxA5U9ER6LvmDe2kTapS-AtpGWAEf/edit#slide=id.p2) |
| Sept 9 | Basic Text Processing, Edit-distance |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/2.pdf) | [Link](https://docs.google.com/presentation/d/1tQdV4Rcgz-bHfqLfGA5b2aWIvowhzUY1/edit#slide=id.p28) [Link](https://docs.google.com/presentation/d/1BF6DN1jSjq4MNQsLn_YL9u7P46ZA88fs/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Sept 11 | Language Models |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/3.pdf) | [Link](https://docs.google.com/presentation/d/1sz2QbHAAS-UdIUmUnQ31fmwoPwQYb1Vw/edit#slide=id.p12) |
| Sep 16 | Spelling corrections  |  |  | [Link](https://docs.google.com/presentation/d/1xZpM-50waYY9KM3QD8RM4RmzSXfq70vP/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) [Link](https://drive.google.com/file/d/12eJQOTVgK5g8aXN0yppNYKaMruH9SMyG/view) |
| Sep 18 | Large Language Models(LLMs)  \[ by Siyan Li\] |  | **[Link](https://web.stanford.edu/~jurafsky/slp3/7.pdf)** | [Link](https://drive.google.com/file/d/12eJQOTVgK5g8aXN0yppNYKaMruH9SMyG/view) [Link](https://docs.google.com/presentation/d/1K90kzxSHfZNaVZXU8XmywgPpyd_MPxCq/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Sep 21, 11am | Tutorials on Python |  |  |  |
| Sep 23 | Basic Neural Networks, |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/9.pdf) | [Link](https://docs.google.com/presentation/d/1yOPi9oD52wwmFe6SWtpZ7IzWv4yvIUSu/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Sep 25 | skip |  |  |  |
| Sep 28, 11am | Tutorials on Pytorch |  |  |  |
| Sep 30 | Transformers, Vector Semantics |  | [Link](https://jalammar.github.io/illustrated-transformer/) [**Link**](https://web.stanford.edu/~jurafsky/slp3/10.pdf) | [Link](https://docs.google.com/presentation/d/1mIqp55sSua6gy-Lrv5nIYOLvSVMcYEVZSRlq8TEkCh8/edit#slide=id.p) [Link](https://drive.google.com/file/d/1GkNPXJ8et5AlsAllIBLjOLNA3VDplmkK/view?usp=sharing) |
| Oct 2 |  Vector Semantics |  |  [**Link**](https://web.stanford.edu/~jurafsky/slp3/10.pdf) |  [Link](https://drive.google.com/file/d/1GkNPXJ8et5AlsAllIBLjOLNA3VDplmkK/view?usp=sharing) |
| Oct 7 | POS Tagging |  | [Link](http://web.stanford.edu/~jurafsky/slp3/8.pdf) | [Link](https://drive.google.com/file/d/1IGBUs_ou6_5pIA4yvK5g5KcedZe8MFQt/view?usp=sharing) |
| Oct 9 (Wed) | POS Tagging/Parsing |  | [**Link**](http://web.stanford.edu/~jurafsky/slp3/8.pdf)  [Link](https://web.stanford.edu/~jurafsky/slp3/A.pdf) | [Link](https://drive.google.com/file/d/15rDMUXoqvm6xicuqzHLA8JRIhOA0FKah/view?usp=sharing) |
| Oct 14 (Mon) | Advanced Semantics  |  |  | [Link](https://drive.google.com/file/d/1Na0lKxO0-p2PeTWrqm9SsuK1RrVvjpZE/view?usp=sharing) |
| Oct 16 (Wed) | Prompting \+ Finetuning \+ RLHF |  |  | [**link**](https://drive.google.com/file/d/1pumyRtK_ZaQuNGUXWki_Uybb_Un4KFwP/view?usp=sharing) |
| Oct 21 (Mon) | Machine Translation |   | [**link**](https://web.stanford.edu/~jurafsky/slp3/13.pdf) | [**Link**](https://drive.google.com/file/d/1Sx1m--q-FCh4skIjvyKd1z01FYhUZaR6/view?usp=sharing) |
| Oct 23 (Wed) | Sentiment Analysis |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/25.pdf) | [Link](https://drive.google.com/file/d/1ACGHR2uw-_i0SoCnHTFyBnATTAJEM-sZ/view?usp=sharing) |
| Oct 28 (Mon) | Mid-term |  |  |  |
| Oct 30 (Wed) | Information Extraction |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/21.pdf) | [Link](https://drive.google.com/file/d/1YE0mhYgM7X492Slp22To4HEOHcu1JHjf/view?usp=sharing) |
| Nov  4 (Mon) | Academic Holiday |  |  |  |
| Nov 6 (Wed) |  Language Generation \[Zachary Horvitz\] |  |  | [Link](https://docs.google.com/presentation/d/1B685Gchn3j9zCeD6JMz5LlLmaNVN6qXw/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Nov 11 (Mon) | Summarization |  |  | [Link](https://docs.google.com/presentation/d/1HEyJobR7xrS0rLFgLwwraZNbAdb2EGa4/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Nov 13 (Wed) | Bias and Ethics \[Matthew Toles\] |  |  | [link](https://docs.google.com/presentation/d/13aQTnTxj5DTvb5UoFlqU8iNySotewZeE1mJiQqPaS10/edit#slide=id.g2bff1bebd7b_0_0) |
| Nov 18(Mon) | Question Answering \[Yu Li\] |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/14.pdf) | [Link](https://drive.google.com/file/d/1dtK8cDsfGAgsr8hsf_rx4cxDMc8Iz7CB/view?usp=sharing) |
| Nov 20 (Wed) | Dialogs \[Max Chen\] |  | [**Link**](https://web.stanford.edu/~jurafsky/slp3/15.pdf) | [Link](https://drive.google.com/file/d/1iv4Jt3bnTvkWkdhB6xyyBLWO6miUd_8b/view?usp=sharing) |
| Nov 25 (Mon) | (V)LM Agents \[Xiao Yu\] |  |  | [Link](https://drive.google.com/file/d/13fdScOtjbm8Xlk9gB-nm5bWwIN6zWzVj/view?usp=sharing) |
| Nov 27 (Wed) | School holiday |  |  |  |
| Dec 2 (Mon) | Human-centered NLP \[Xuanming Zhang\]  |  |  | [Link](https://docs.google.com/presentation/d/1M6oSprTZwWNn44GwaiUc4CPY1eiMFHPRruHCNWFN3TA/edit?usp=sharing) |
| Dec 4 (Wed) | RAG \+ Fact Checking |  |  | [link](https://docs.google.com/presentation/d/1A7jelRkbubVOLKKoquV3OZeD4d2lN5U8/edit?usp=sharing&ouid=109231055856631695291&rtpof=true&sd=true) |
| Dec 9 (Mon) | Final Exam |  |  |  |
|  |  |  |  |  |
